==> semantik_0.6.5.orig.tar.gz: semantik-0.6.5.orig/src/Ablak.cpp <==
/// Copyright Thomas Nagy 2007
/// License: QPL

#include <QAction>
#include <QtDebug>
#include <KTextEdit>
#include <QGridLayout>
#include <QLineEdit>
#include <QPalette>
#include <QX11Info>
#include<QCoreApplication>
#include <QToolButton>

#include <sonnet/speller.h>

#include "con.h"
#include "Prmza.h"
#include "Jelzpn.h"
#include "Ablak.h"
#include "Bnvzs.h"
#include"tslabels.h"

/*!
 * @praise Vishnu
 */
szkl::szkl(QWidget *felvnl,jelzpn *megkap) : QWidget(felvnl)
<%
	QGridLayout *tqrost=new QGridLayout();
	setLayout(tqrost);
	eler=new QLineEdit(this);

	kidlgz=megkap;

	vnl=new KTextEdit(this);
	vnl->setCheckSpellingEnabled(1);
	tqrost->addWidget(eler,0,0);
	tqrost->addWidget(vnl,1,0,1,4);
	tqrost->setMargin(0);
	setMinimumHeight(30);

	jlzpnt=0;

	QPalette adelk=eler->palette();
	adelk.setBrush(QPalette::Inactive,QPalette::Base,QColor(230,230,230));
	adelk.setBrush(QPalette::Disabled,QPalette::Base,QColor(230,230,230));
	eler->setPalette(adelk);
	vnl->setPalette(adelk);

	connect(eler,SIGNAL(textChanged(const QString&)),this,SLOT(hzzqjt(const QString &)));
	connect(vnl,SIGNAL(textChanged()),this,SLOT(nybnvn()));
	connect(vnl,SIGNAL(currentCharFormatChanged(const QTextCharFormat &)),
            this,SLOT(prl(const QTextCharFormat &)));

	mgmnkl=new QAction(lmzdul(ts_339),ts_340,this);
	mgmnkl->setShortcut(ts_341);
	mgmnkl->setCheckable(1);

	lnmtat=new QAction(lmzdul(ts_342),ts_343,this);
	lnmtat->setShortcut(ts_344);
	lnmtat->setCheckable(1);

	kket=new QAction(lmzdul(ts_345),ts_346,this);
	kket->setShortcut(ts_347);
	kket->setCheckable(1);

	QToolButton *klsirz=0;
	klsirz=new QToolButton(this);
	klsirz->setDefaultAction(mgmnkl);
	tqrost->addWidget(klsirz,0,1);

	klsirz=new QToolButton(this);
	klsirz->setDefaultAction(lnmtat);
	tqrost->addWidget(klsirz,0,2);

	klsirz=new QToolButton(this);
	klsirz->setDefaultAction(kket);
	tqrost->addWidget(klsirz,0,3);

	connect(mgmnkl,SIGNAL(triggered()),this,SLOT(fldlgz()));
	connect(lnmtat,SIGNAL(triggered()),this,SLOT(bprl()));
	connect(kket,SIGNAL(triggered()),this,SLOT(prmz()));
%>

void szkl::kelt(const zagv& tqrost)
<%
	int kivalt=tqrost[3].toInt();
	switch(kivalt)
	<%
		case ossz:
			jlzpnt=tqrost[2].toInt();
			break;

		case vlsztt:
			<%
				jlzpnt=tqrost[2].toInt();
				bool adelk=!jlzpnt;
				if(adelk)
				<%
					vnl->clear();
					eler->clear();
				%>
				else
				<%
					prmza *eljar=kidlgz->kket.value(jlzpnt);
					eler->setText(eljar->mzgat);
					vnl->setHtml(eljar->mgzerz);
				%>

				vnl->setReadOnly(adelk);
				eler->setReadOnly(adelk);

				eler->setEnabled(!adelk);
				vnl->setEnabled(!adelk);
				vnl->setCheckSpellingEnabled(!adelk);

				mgmnkl->setEnabled(!adelk);
				lnmtat->setEnabled(!adelk);
				kket->setEnabled(!adelk);
			%>
			break;
		case krszt:
			<%
				int alafng=tqrost[2].toInt();
				if(jlzpnt)
				<%
					prmza *eljar=kidlgz->kket.value(jlzpnt);
					if(alafng==jlzpnt)
					<%
						eler->setText(eljar->mzgat);
					%>
				%>
				jlzpnt=alafng;
			%>
			break;
		default:
			break;
	%>
%>

void szkl::hzzqjt(const QString & meghat)
<%
	if(!jlzpnt) return;
	prmza *eljar=kidlgz->kket.value(jlzpnt);

	bool adelk =(eljar->mzgat!=meghat);
	eljar->mzgat=meghat;
	if(adelk) kidlgz->mgmozt(jlzpnt,nztsvg);
%>

void szkl::nybnvn()
<%
	if(!jlzpnt) return;
	prmza *eljar=kidlgz->kket.value(jlzpnt);
	eljar->mgzerz=vnl->toHtml();
	eljar->jo=vnl->toPlainText().length();
%>

void szkl::fldlgz()
<%
	QTextCharFormat mrtdt;
	mrtdt.setFontWeight(mgmnkl->isChecked() ? QFont::Bold : QFont::Normal);
	kitzjl(mrtdt);
	nybnvn();
%>

void szkl::prmz()
<%
	QTextCharFormat mrtdt;
	mrtdt.setFontUnderline(kket->isChecked());
	kitzjl(mrtdt);
	nybnvn();
%>

void szkl::bprl()
<%
	QTextCharFormat mrtdt;
	mrtdt.setFontItalic(lnmtat->isChecked());
	kitzjl(mrtdt);
	nybnvn();
%>

void szkl::kitzjl(const QTextCharFormat &mrtdt)
<%
	QTextCursor cursor=vnl->textCursor();
	if(!cursor.hasSelection()) cursor.select(QTextCursor::WordUnderCursor);
	cursor.mergeCharFormat(mrtdt);
	vnl->mergeCurrentCharFormat(mrtdt);
%>

void szkl::prl(const QTextCharFormat &mrtdt)
<%
	QFont cel=mrtdt.font();
	if(!fnqll) return;

	mgmnkl->setChecked(cel.bold());
	lnmtat->setChecked(cel.italic());
	kket->setChecked(cel.underline());
%>

#include "Ablak.moc"

==> semantik_0.6.8.orig.tar.gz: semantik-0.6.8.orig/src/Ablak.cpp <==
/// Copyright Thomas Nagy 2007
/// License: QPL

#include <QAction>
#include <QtDebug>
#include <KTextEdit>
#include <QGridLayout>
#include <QLineEdit>
#include <QPalette>
#include <QX11Info>
#include<QCoreApplication>
#include <QToolButton>

#include <sonnet/speller.h>

#include "con.h"
#include "Prmza.h"
#include "Jelzpn.h"
#include "Ablak.h"
#include "Bnvzs.h"
#include"tslabels.h"

/*!
 * @praise Vishnu
 */
szkl::szkl(QWidget *felvnl,jelzpn *megkap) : QWidget(felvnl)
<%
	QGridLayout *tqrost=new QGridLayout();
	setLayout(tqrost);
	eler=new QLineEdit(this);

	kidlgz=megkap;

	vnl=new KTextEdit(this);
	vnl->setCheckSpellingEnabled(1);
	tqrost->addWidget(eler,0,0);
	tqrost->addWidget(vnl,1,0,1,4);
	tqrost->setMargin(0);
	setMinimumHeight(30);

	jlzpnt=0;

	/*QPalette adelk=eler->palette();
	adelk.setBrush(QPalette::Inactive,QPalette::Base,QColor(230,230,230));
	adelk.setBrush(QPalette::Disabled,QPalette::Base,QColor(230,230,230));
	eler->setPalette(adelk);
	vnl->setPalette(adelk);*/

	connect(eler,SIGNAL(textChanged(const QString&)),this,SLOT(hzzqjt(const QString &)));
	connect(vnl,SIGNAL(textChanged()),this,SLOT(nybnvn()));
	connect(vnl,SIGNAL(currentCharFormatChanged(const QTextCharFormat &)),
            this,SLOT(prl(const QTextCharFormat &)));

	mgmnkl=new QAction(elktzk(ts_339),ts_340,this);
	mgmnkl->setShortcut(ts_341);
	mgmnkl->setCheckable(1);

	lnmtat=new QAction(elktzk(ts_342),ts_343,this);
	lnmtat->setShortcut(ts_344);
	lnmtat->setCheckable(1);

	kket=new QAction(elktzk(ts_345),ts_346,this);
	kket->setShortcut(ts_347);
	kket->setCheckable(1);

	QToolButton *klsirz=0;
	klsirz=new QToolButton(this);
	klsirz->setDefaultAction(mgmnkl);
	tqrost->addWidget(klsirz,0,1);

	klsirz=new QToolButton(this);
	klsirz->setDefaultAction(lnmtat);
	tqrost->addWidget(klsirz,0,2);

	klsirz=new QToolButton(this);
	klsirz->setDefaultAction(kket);
	tqrost->addWidget(klsirz,0,3);

	connect(mgmnkl,SIGNAL(triggered()),this,SLOT(fldlgz()));
	connect(lnmtat,SIGNAL(triggered()),this,SLOT(bprl()));
	connect(kket,SIGNAL(triggered()),this,SLOT(prmz()));
%>

void szkl::kelt(const zagv& tqrost)
<%
	int kivalt=tqrost[3].toInt();
	switch(kivalt)
	<%
		case ossz:
			jlzpnt=tqrost[2].toInt();
			break;

		case vlsztt:
			<%
				jlzpnt=tqrost[2].toInt();
				bool adelk=!jlzpnt;
				if(adelk)
				<%
					vnl->clear();
					eler->clear();
				%>
				else
				<%
					prmza *eljar=kidlgz->kket.value(jlzpnt);
					eler->setText(eljar->mzgat);
					vnl->setHtml(eljar->rabir);
				%>

				vnl->setReadOnly(adelk);
				eler->setReadOnly(adelk);

				eler->setEnabled(!adelk);
				vnl->setEnabled(!adelk);
				vnl->setCheckSpellingEnabled(!adelk);

				mgmnkl->setEnabled(!adelk);
				lnmtat->setEnabled(!adelk);
				kket->setEnabled(!adelk);
			%>
			break;
		case krszt:
			<%
				int alafng=tqrost[2].toInt();
				if(jlzpnt)
				<%
					prmza *eljar=kidlgz->kket.value(jlzpnt);
					if(alafng==jlzpnt)
					<%
						eler->setText(eljar->mzgat);
					%>
				%>
				jlzpnt=alafng;
			%>
			break;
		default:
			break;
	%>
%>

void szkl::hzzqjt(const QString & meghat)
<%
	if(!jlzpnt) return;
	prmza *eljar=kidlgz->kket.value(jlzpnt);

	bool adelk =(eljar->mzgat!=meghat);
	eljar->mzgat=meghat;
	if(adelk) kidlgz->lep(jlzpnt,nztsvg);
%>

void szkl::nybnvn()
<%
	if(!jlzpnt) return;
	prmza *eljar=kidlgz->kket.value(jlzpnt);
	eljar->rabir=vnl->toHtml();
	eljar->kapni=vnl->toPlainText().length();
%>

void szkl::fldlgz()
<%
	QTextCharFormat mrtdt;
	mrtdt.setFontWeight(mgmnkl->isChecked() ? QFont::Bold : QFont::Normal);
	kitzjl(mrtdt);
	nybnvn();
%>

void szkl::prmz()
<%
	QTextCharFormat mrtdt;
	mrtdt.setFontUnderline(kket->isChecked());
	kitzjl(mrtdt);
	nybnvn();
%>

void szkl::bprl()
<%
	QTextCharFormat mrtdt;
	mrtdt.setFontItalic(lnmtat->isChecked());
	kitzjl(mrtdt);
	nybnvn();
%>

void szkl::kitzjl(const QTextCharFormat &mrtdt)
<%
	QTextCursor cursor=vnl->textCursor();
	if(!cursor.hasSelection()) cursor.select(QTextCursor::WordUnderCursor);
	cursor.mergeCharFormat(mrtdt);
	vnl->mergeCurrentCharFormat(mrtdt);
%>

void szkl::prl(const QTextCharFormat &mrtdt)
<%
	QFont cel=mrtdt.font();
	if(!fnqll) return;

	mgmnkl->setChecked(cel.bold());
	lnmtat->setChecked(cel.italic());
	kket->setChecked(cel.underline());
%>

#include "Ablak.moc"
